@@ -1,4 +1,4 @@
 from .api import User
-from .api import get_day, get_time
+from .helper import get_day, get_time, get_seat_id
 
-# from leolib import User, get_day, get_time
\ No newline at end of file
+# from leolib import User, get_day, get_time
